| long_format_to_iq_format | R Documentation |
This function reads long-format input data, filters it, and writes the results to the iq format.
long_format_to_iq_format(input_data,
output_data,
sample_id = "Run",
primary_id = "Protein.Group",
secondary_id = c("Precursor.Id"),
intensity_col = "Intensities",
annotation_col = NULL,
filter_string_equal = NULL,
filter_string_not_equal = NULL,
filter_double_less = NULL,
filter_double_greater = NULL,
intensity_col_sep = ";",
intensity_col_id = NULL,
na_string = "0",
normalization = "median",
log2_intensity_cutoff = 0,
pdf_out = "qc-plots-iq.pdf",
pdf_width = 12,
pdf_height = 8,
show_boxplot = FALSE)
input_data |
See |
output_data |
Output data. |
sample_id |
See |
primary_id |
See |
secondary_id |
See |
intensity_col |
See |
annotation_col |
See |
filter_string_equal |
See |
filter_string_not_equal |
See |
filter_double_less |
See |
filter_double_greater |
See |
intensity_col_sep |
See |
intensity_col_id |
See |
na_string |
See |
normalization |
Normalization type. Possible values are |
log2_intensity_cutoff |
See |
pdf_out |
See |
pdf_width |
See |
pdf_height |
See |
show_boxplot |
See |
The output is written to a new directory named output_data.
Thang V. Pham
Pham TV, Henneman AA, Jimenez CR. iq: an R package to estimate relative protein abundances from ion quantification in DIA-MS-based proteomics. Bioinformatics 2020 Apr 15;36(8):2611-2613.
fast_read, fast_preprocess
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.