process_iq_format: Process data in the iq format

View source: R/iq-format.R

process_iq_formatR Documentation

Process data in the iq format

Description

Estimates protein abundance of all proteins in the iq format data.

Usage

process_iq_format(input_data,
                  output_filename = NULL,
                  method = "maxlfq_bit", 
                  p1 = NULL, p2 = NULL, k = 1.345, min_M = 15, n_threads = -1,
                  rescale_method = NULL)

Arguments

input_data

Input data in the iq format.

output_filename

Output file name. If NULL, a file name derived from input_data will be used.

method

See method in process_matrix.

p1

See p1 in process_matrix.

p2

See p2 in process_matrix.

k

See k in process_matrix.

min_M

See min_M in process_matrix.

n_threads

See n_threads in process_matrix.

rescale_method

Rescale the output intensities. See method in rescale.

Value

A tab-separated table with rows representing proteins and columns representing protein annotations and samples.

Author(s)

Thang V. Pham

References

Pham TV, Henneman AA, Jimenez CR. iq: an R package to estimate relative protein abundances from ion quantification in DIA-MS-based proteomics. Bioinformatics 2020 Apr 15;36(8):2611-2613.


iq documentation built on March 21, 2026, 5:07 p.m.