| process_matrix | R Documentation |
Estimates a row vector best representing all rows in the input numeric matrix.
process_matrix(X,
method,
p1 = NULL, p2 = NULL, k = 1.345, min_M = 15, n_threads = -1)
X |
A matrix of intensities in the log2 space. Columns are samples and rows are fragment ions. |
method |
One of the quantification methods: |
p1 |
Method parameter. For |
p2 |
Method parameter. For |
k |
Weighting function parameter. |
min_M |
Minimum number of rows for the weighted methods. |
n_threads |
The number of threads to be used. When |
A numeric row vector.
Thang V. Pham
Pham TV, Henneman AA, Jimenez CR. iq: an R package to estimate relative protein abundances from ion quantification in DIA-MS-based proteomics. Bioinformatics 2020 Apr 15;36(8):2611-2613.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.