| process_iq_format | R Documentation |
Estimates protein abundance of all proteins in the iq format data.
process_iq_format(input_data,
output_filename = NULL,
method = "maxlfq_bit",
p1 = NULL, p2 = NULL, k = 1.345, min_M = 15, n_threads = -1,
rescale_method = NULL)
input_data |
Input data in the iq format. |
output_filename |
Output file name. If |
method |
See |
p1 |
See |
p2 |
See |
k |
See |
min_M |
See |
n_threads |
See |
rescale_method |
Rescale the output intensities. See |
A tab-separated table with rows representing proteins and columns representing protein annotations and samples.
Thang V. Pham
Pham TV, Henneman AA, Jimenez CR. iq: an R package to estimate relative protein abundances from ion quantification in DIA-MS-based proteomics. Bioinformatics 2020 Apr 15;36(8):2611-2613.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.